@@ -16,5 +16,10 @@ backgroundColor = (255, 255, 255)
 global mousePosition
 mousePosition = (0, 0)
 
+oldMousePosition = (0, 0)
+
 global screenRect
-screenRect = (800, 600)
\ No newline at end of file
+screenRect = (800, 600)
+
+global mouseDragging
+mouseDragging = False
\ No newline at end of file
